package com.chelvc.cloud.vehicle.client;

import java.util.List;
import java.util.Map;

import com.chelvc.cloud.vehicle.client.constant.GoodsStatus;
import com.chelvc.cloud.vehicle.client.dto.GoodsDTO;
import com.chelvc.cloud.vehicle.client.dto.GoodsDetailDTO;
import com.chelvc.cloud.vehicle.client.param.GoodsModifyParam;
import com.chelvc.cloud.vehicle.client.param.GoodsPagingParam;
import com.chelvc.cloud.vehicle.client.param.GoodsQueryParam;
import com.chelvc.framework.common.model.Pagination;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.cloud.openfeign.SpringQueryMap;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * 商品业务接口
 *
 * @author Woody
 * @date 2023/8/6
 */
@FeignClient("vehicle")
public interface GoodsClient {
    /**
     * 获取商品详情
     *
     * @param id 商品ID
     * @return 商品详情
     */
    @GetMapping("/goods/getGoodsDetail")
    GoodsDetailDTO getGoodsDetail(@RequestParam("id") Long id);

    /**
     * 查询商家商品
     *
     * @param merchantId 商家ID
     * @param param      查询参数
     * @return 商品列表
     */
    @GetMapping("/goods/listMerchantSimpleGoods")
    List<GoodsDTO> listMerchantSimpleGoods(@RequestParam("merchantId") Long merchantId,
                                           @SpringQueryMap GoodsQueryParam param);


    /**
     * 新增商品
     *
     * @param param 新增参数
     * @return 商品主键
     */
    @PostMapping("/goods/addGoods")
    Long addGoods(@RequestBody GoodsModifyParam param);

    /**
     * 修改商品
     *
     * @param id    商品主键
     * @param param 修改参数
     */
    @PutMapping("/goods/updateGoods")
    void updateGoods(@RequestParam("id") Long id, @RequestBody GoodsModifyParam param);

    /**
     * 删除商品
     *
     * @param id 商品主键
     */
    @DeleteMapping("/goods")
    void deleteGoods(@RequestParam("id") Long id);

    /**
     * 查询商品
     *
     * @param param 查询参数
     * @return 商品分页信息
     */
    @GetMapping("/goods/getGoodsPaging")
    Pagination<GoodsDTO> getGoodsPaging(@SpringQueryMap GoodsPagingParam param);

    /**
     * 修改商品状态
     *
     * @param ids    商品ID集合
     * @param status 商品状态
     */
    @PutMapping("/goods/updateGoodsStatus")
    void updateGoodsStatus(@RequestParam("ids") List<Long> ids, @RequestParam("status") GoodsStatus status);

    /**
     * 商家端商品管理
     *
     * @param param
     * @return
     */
    @GetMapping("/goods/getMerchantGoodsList")
    List<GoodsDTO> getMerchantGoodsList(@SpringQueryMap GoodsQueryParam param);

    /**
     * 获取商品的订单量以及交易金额
     *
     * @return
     */
    @GetMapping("/goods/getGoodsAmount")
    List<Map<String, Object>> getGoodsAmount();
}
