package com.chelvc.cloud.vehicle.server.controller;


import java.util.List;

import com.chelvc.cloud.vehicle.client.dto.MerchantDTO;
import com.chelvc.cloud.vehicle.client.param.LocationQueryParam;
import com.chelvc.cloud.vehicle.server.service.HotMerchantService;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * 热门搜索接口
 *
 * @author liude
 * @data 2023/12/31
 */
@RestController
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class HotMerchantController {

    private final HotMerchantService hotMerchantService;

    /**
     * 新增热门搜索
     *
     * @param id 新增参数
     * @return 热门搜索主键
     */
    @PostMapping("/hotMerchant/addHotMerchant")
    public Long addHotMerchant(@RequestParam("id") Long id) {
        return hotMerchantService.addHotMerchant(id);
    }

    /**
     * 热门搜索商家
     *
     * @return
     */
    @GetMapping("/hotMerchant/listHotMerchant")
    public List<MerchantDTO> listHotMerchant(LocationQueryParam param) {
        return hotMerchantService.listHotMerchant(param);
    }


    /**
     * 猜你喜欢的商家
     *
     * @return
     */
    @GetMapping("/hotMerchant/likeMerchant")
    public List<MerchantDTO> likeMerchant(LocationQueryParam param) {
        return hotMerchantService.likeMerchant(param);
    }
}
