package com.chelvc.cloud.vehicle.server.dao;

import java.util.List;
import java.util.Map;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.chelvc.cloud.vehicle.client.constant.CategoryType;
import com.chelvc.cloud.vehicle.client.dto.GoodsDTO;
import com.chelvc.cloud.vehicle.client.param.GoodsQueryParam;
import com.chelvc.cloud.vehicle.server.entity.Goods;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

/**
 * 商品数据操作接口
 *
 * @author Woody
 * @date 2023/7/17
 */
@Mapper
public interface GoodsMapper extends BaseMapper<Goods> {
    /**
     * 查询商家商品
     *
     * @param merchantId 商家ID
     * @param param      查询参数
     * @return 商品列表
     */
    List<GoodsDTO> listMerchantSimpleGoods(@Param("merchantId") Long merchantId, @Param("param") GoodsQueryParam param);

    /**
     * 获取商家商品分类类型
     *
     * @param merchantId 商家ID
     * @return 分类类型列表
     */
    List<CategoryType> listMerchantGoodsCategoryTypes(@Param("merchantId") Long merchantId);

    /**
     * 商品是否被收藏
     * @param goodsId
     * @return
     */
    Integer goodsFavorite(@Param("goodsId") Long goodsId,@Param("userId") Long userId);


    /**
     * 获取商品的订单量以及交易金额
     * @param merchantId
     * @return
     */
    List<Map<String,Object>> getGoodsAmount(Long merchantId);
}
