package com.chelvc.cloud.vehicle.server.dao;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.chelvc.cloud.vehicle.client.dto.MerchantReservationDTO;
import com.chelvc.cloud.vehicle.client.dto.OrderItemDTO;
import com.chelvc.cloud.vehicle.client.param.ReservationPagingParam;
import com.chelvc.cloud.vehicle.client.param.ReservationQueryParam;
import com.chelvc.cloud.vehicle.server.entity.Reservation;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 预约记录数据操作接口
 *
 * @author Woody
 * @date 2023/7/17
 */
@Mapper
public interface ReservationMapper extends BaseMapper<Reservation> {

    /**
     * 查询用户预约列表
     *
     * @param param 查询参数
     * @return 用户预约列表
     */
    List<Reservation> listUserReservations(@Param("userId") Long userId, @Param("param") ReservationQueryParam param);
    /**
     * 更新预约单的状态
     * @param id 预约单ID
     * @param status 预约单的状态
     */
    void updateReservationsStatus(@Param("id")Long id,@Param("status")String status);

    /**
     * 分页查询商家端预约信息
     * @param page 分页信息
     * @param param 参数
     * @return
     */
    Page<MerchantReservationDTO> getMerchantReservationPaging(IPage<ReservationPagingParam> page, @Param("param")ReservationPagingParam param);

    /**
     * 查询预约的商品列表
     * @param orderId 订单 id
     * @return
     */
    List<OrderItemDTO> getReservationRetail(Long orderId);

}
