package com.chelvc.cloud.vehicle.server.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chelvc.cloud.vehicle.client.constant.PlatformConstant;
import com.chelvc.cloud.vehicle.client.dto.MerchantAssetDTO;
import com.chelvc.cloud.vehicle.client.dto.MerchantTeamDTO;
import com.chelvc.cloud.vehicle.client.dto.OrderDTO;
import com.chelvc.cloud.vehicle.client.dto.WalletDTO;
import com.chelvc.cloud.vehicle.server.dao.AssetMapper;
import com.chelvc.cloud.vehicle.server.entity.Asset;
import com.chelvc.cloud.vehicle.server.service.AssetService;
import com.chelvc.cloud.vehicle.server.service.BalanceDetailService;
import com.chelvc.cloud.vehicle.server.service.OmsOrderService;
import com.chelvc.framework.common.exception.ResourceUnavailableException;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.time.LocalDateTime;

@Service
@RequiredArgsConstructor(onConstructor = @__({@Autowired,@Lazy}))
public class AssetServiceImpl extends ServiceImpl<AssetMapper, Asset> implements AssetService {
    private final BalanceDetailService balanceDetailService;
    private final OmsOrderService orderService;

    @Override
    public Asset queryAsset(Long userId, Integer type) {
        LambdaQueryWrapper<Asset> wrapper = Wrappers.lambdaQuery();
        wrapper.eq(Asset::getUserId, userId);
        wrapper.eq(Asset::getType, type);
        Asset asset = baseMapper.selectOne(wrapper);
        if (asset != null) {
            return asset;
        }
        asset = new Asset();
        asset.setFrozen(new BigDecimal("0"));
        asset.setType(type);
        asset.setTotal(new BigDecimal("0"));
        asset.setUpdateTime(LocalDateTime.now());
        asset.setUserId(userId);
        baseMapper.insert(asset);
        return asset;
    }

    @Override
    public BigDecimal updateAsset(Integer operateType, BigDecimal operateAmount, Long userId, Integer type, Integer amountType) {
        Asset asset = queryAsset(userId, type);
        if(amountType == 1){
            BigDecimal total = asset.getTotal();
            if (operateType == 1 && total.compareTo(operateAmount) < 0) {
                throw new ResourceUnavailableException("账户余额不足");
            }
            if (operateType == 0) {
                asset.setTotal(total.add(operateAmount));
            } else if (operateType == 1) {
                asset.setTotal(total.subtract(operateAmount));
            }
        } else if(amountType == 2){
            BigDecimal frozen = asset.getFrozen();
            if (operateType == 1 && frozen.compareTo(operateAmount) < 0) {
                throw new ResourceUnavailableException("账户冻结余额不足");
            }
            if (operateType == 0) {
                asset.setFrozen(frozen.add(operateAmount));
            } else if (operateType == 1) {
                asset.setFrozen(frozen.subtract(operateAmount));
            }
        }
        asset.setUpdateTime(LocalDateTime.now());
        int i = baseMapper.updateById(asset);
        if (i != 1) {
            throw new ResourceUnavailableException("操作失败");
        }
        return asset.getTotal();
    }

    @Override
    public void updatePlatformAsset(BigDecimal platformRealityAmount, BigDecimal payAmount) {
        Asset asset = queryAsset(PlatformConstant.PLATFORM_ID, 0);
        BigDecimal frozen = asset.getFrozen();
        if(frozen.compareTo(payAmount) < 0){
            throw new ResourceUnavailableException("账户冻结余额不足");
        }
        baseMapper.updatePlatformAsset(platformRealityAmount, payAmount, LocalDateTime.now(), PlatformConstant.PLATFORM_ID);
    }

    @Override
    public MerchantAssetDTO getMerchantAsset(Long merchantId) {
        if(merchantId == null){
            return null;
        }
        MerchantAssetDTO dto = new MerchantAssetDTO();
        WalletDTO walletDTO = balanceDetailService.getMerchantAsset(merchantId);
        LambdaQueryWrapper<Asset> wrapper = Wrappers.lambdaQuery();
        wrapper.eq(Asset::getUserId, merchantId);
        wrapper.eq(Asset::getType, 2);
        Asset asset = baseMapper.selectOne(wrapper);
        if(asset != null){
            BigDecimal total = asset.getTotal();
            BigDecimal frozen = asset.getFrozen();
            walletDTO.setAsset(total);
            walletDTO.setWithdraw(total.subtract(frozen));
        }
        dto.setWalletDTO(walletDTO);
        OrderDTO orderDTO = orderService.queryOrderManage(merchantId);
        dto.setOrderDTO(orderDTO);
        MerchantTeamDTO merchantTeamDTO = orderService.queryTeamOrder(merchantId);
        dto.setMerchantTeamDTO(merchantTeamDTO);
        return dto;
    }
}
