package com.chelvc.cloud.vehicle.server.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chelvc.cloud.vehicle.client.dto.CurrencyRecordDTO;
import com.chelvc.cloud.vehicle.client.dto.EarningsDTO;
import com.chelvc.cloud.vehicle.server.copier.CurrencyRecordCopier;
import com.chelvc.cloud.vehicle.server.dao.CurrencyRecordMapper;
import com.chelvc.cloud.vehicle.server.entity.Asset;
import com.chelvc.cloud.vehicle.server.entity.CurrencyRecord;
import com.chelvc.cloud.vehicle.server.service.AssetService;
import com.chelvc.cloud.vehicle.server.service.CurrencyRecordService;
import com.chelvc.framework.base.context.SessionContextHolder;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.util.List;

/**
 * 收益流水记录表操作接口
 *
 * @author liude
 * @date 2024/03/15
 */
@Service
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class CurrencyRecordServiceImpl extends ServiceImpl<CurrencyRecordMapper, CurrencyRecord> implements CurrencyRecordService {

    private final AssetService assetService;

     @Override
     public List<CurrencyRecordDTO> listCurrencyRecord(Integer type){
      Long userId = SessionContextHolder.getId();
         List<CurrencyRecord> currencyRecords = this.lambdaQuery()
                 .eq(CurrencyRecord::getUserId,userId)
                 .eq(CurrencyRecord::getType, type)
                 .list();
      return CurrencyRecordCopier.INSTANCE.copying(currencyRecords);
     }
    @Override
    public EarningsDTO getCurrencyRecord(Integer type){
        Long userId = SessionContextHolder.getId();
        EarningsDTO currencyRecord = this.baseMapper.getCurrencyRecord(userId, type);
        if(currencyRecord == null){
            currencyRecord = new EarningsDTO();
        }
        Asset asset = assetService.queryAsset(userId, type);
        if(asset == null){
            currencyRecord.setWithdrawAmount(BigDecimal.ZERO);
        } else {
            currencyRecord.setWithdrawAmount(asset.getTotal());
        }
        return currencyRecord;
    }

    @Override
    public void recordFlow(Long userId, Integer type, Integer currencyType, Long orderId, Long sourceId,
                           Integer sourceType, BigDecimal amount, BigDecimal deduct, BigDecimal realityAmount) {
        CurrencyRecord currencyRecord = new CurrencyRecord();
        currencyRecord.setUserId(userId);
        currencyRecord.setType(type);
        currencyRecord.setCurrencyType(currencyType);
        currencyRecord.setOrderId(orderId);
        currencyRecord.setSourceId(sourceId);
        currencyRecord.setSourceType(sourceType);
        currencyRecord.setAmount(amount);
        currencyRecord.setDeduct(deduct);
        currencyRecord.setRealityAmount(realityAmount);
        currencyRecord.setCreateTime(LocalDateTime.now());
        baseMapper.insert(currencyRecord);
    }
}
