package com.chelvc.cloud.vehicle.server.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.chelvc.cloud.user.client.UserClient;
import com.chelvc.cloud.user.client.model.Scope;
import com.chelvc.cloud.vehicle.client.dto.MerchantAuthDTO;
import com.chelvc.cloud.vehicle.client.dto.MerchantDTO;
import com.chelvc.cloud.vehicle.client.param.MerchantAuthModifyParam;
import com.chelvc.cloud.vehicle.client.param.MerchantAuthPagingParam;
import com.chelvc.cloud.vehicle.client.param.MerchantModifyParam;
import com.chelvc.cloud.vehicle.server.copier.MerchantAuthCopier;
import com.chelvc.cloud.vehicle.server.dao.MerchantAuthMapper;
import com.chelvc.cloud.vehicle.server.entity.Merchant;
import com.chelvc.cloud.vehicle.server.entity.MerchantAuth;
import com.chelvc.cloud.vehicle.server.service.MerchantAuthService;
import com.chelvc.cloud.vehicle.server.service.MerchantService;
import com.chelvc.framework.base.context.SessionContextHolder;
import com.chelvc.framework.common.model.Pagination;
import com.chelvc.framework.common.util.AssertUtils;
import com.chelvc.framework.common.util.StringUtils;
import com.chelvc.framework.database.context.DatabaseContextHolder;
import lombok.NonNull;
import lombok.RequiredArgsConstructor;
import org.apache.commons.lang3.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.Date;
import java.util.List;

/**
 * 商家认证业务操作实现
 *
 * @author liude
 * @date 2023/12/2
 */
@Service
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class MerchantAuthServiceImpl extends ServiceImpl<MerchantAuthMapper, MerchantAuth> implements MerchantAuthService{
    private final MerchantService merchantService;

    private final UserClient userClient;
    @Override
    public Long addMerchantAuth(@NonNull MerchantAuthModifyParam param) {
        Long userId = SessionContextHolder.getId();
        if (StringUtils.isEmpty(param.getStoreAddress())){
            param.setStoreAddress(param.getRegion());
        }
        MerchantAuth merchantAuth = MerchantAuthCopier.INSTANCE.copying(param);
        MerchantAuth count = this.lambdaQuery().eq(MerchantAuth::getApplicant, userId).one();
        //AssertUtils.available(count <= 0, "商家认证已存在");
        if (null != count){
            this.updateMerchantAuth(count.getId(),param);
            return count.getId();
        }
        merchantAuth.setApplicationTime(new Date());
        merchantAuth.setApplicant(userId);
        merchantAuth.setReviewStatus("2");
        this.save(merchantAuth);
        MerchantModifyParam param1 = new MerchantModifyParam();
        param1.setName(param.getStoreName());
        param1.setLiaison(param.getLegalRepresentativeName());
        param1.setMobile(param.getMobileNumber());
        param1.setAddress(param.getStoreAddressDetail());
        param1.setRecommend(true);
        param1.setBusinessStatus("1");
        param1.setLogo(param.getStoreImage());
        param1.setOpening(param.getOpening());
        param1.setProvince(param.getProvince());
        param1.setCity(param.getCity());
        param1.setRegion(param.getStoreAddress());
        param1.setDistrict(param.getDistrict());
        param1.setLatitude(param.getLatitude());
        param1.setLongitude(param.getLongitude());
        param1.setMainBusiness(param.getMainBusiness());
        param1.setAncillaryBusiness(param.getAncillaryBusiness());
        param1.setBanners(param.getStoreInnerImage());
        MerchantDTO merchant = this.merchantService.getMerchantByUserId(userId);
        if (ObjectUtils.isEmpty(merchant)){
            this.merchantService.addMerchant(param1);
        }else{
            this.merchantService.updateMerchant(merchant.getId(),param1);
        }

        return merchantAuth.getId();
    }

    @Override
    public void updateMerchantAuth(@NonNull Long id, @NonNull MerchantAuthModifyParam param) {
        if (StringUtils.isEmpty(param.getStoreAddress())){
            param.setStoreAddress(param.getRegion());
        }
        MerchantAuth merchantAuth = AssertUtils.available(this.getById(id), "商家认证不存在");
        MerchantAuthCopier.INSTANCE.copying(param, merchantAuth);
        merchantAuth.setReviewStatus("2");
        merchantAuth.setId(id);
        this.updateById(merchantAuth);
        MerchantModifyParam param1 = new MerchantModifyParam();
        param1.setName(param.getStoreName());
        param1.setLiaison(param.getLegalRepresentativeName());
        param1.setMobile(param.getMobileNumber());
        param1.setAddress(param.getStoreAddressDetail());
        param1.setRecommend(true);
        param1.setBusinessStatus("1");
        param1.setLogo(param.getStoreImage());
        param1.setOpening(param.getOpening());
        param1.setProvince(param.getProvince());
        param1.setCity(param.getCity());
        param1.setRegion(param.getStoreAddress());
        param1.setDistrict(param.getDistrict());
        param1.setLatitude(param.getLatitude());
        param1.setLongitude(param.getLongitude());
        param1.setMainBusiness(param.getMainBusiness());
        param1.setAncillaryBusiness(param.getAncillaryBusiness());
        param1.setBanners(param.getStoreInnerImage());
        Long userId = SessionContextHolder.getId();
        List<Long> merchantIds = this.merchantService.getMerchantIdsByUserId(userId);
        if (CollectionUtils.isEmpty(merchantIds)){
            this.merchantService.addMerchant(param1);
        }else{
            this.merchantService.updateMerchant(merchantIds.get(0),param1);
        }

    }

    @Override
    public Pagination<MerchantAuthDTO> getMerchantAuthPaging(@NonNull MerchantAuthPagingParam param) {
        Long userId = null;
        Scope scope = com.chelvc.framework.common.util.StringUtils.ifEmpty(SessionContextHolder.getScope(), Scope::parse);
        if (scope == Scope.ADMIN) {
        }else {
            userId = SessionContextHolder.getId();
        }
        Page<MerchantAuth> page = this.lambdaQuery()
                .like(StringUtils.notEmpty(param.getStoreName()), MerchantAuth::getStoreName, param.getStoreName())
                .eq(StringUtils.notEmpty(userId),MerchantAuth::getApplicant,userId)
                .orderByAsc(MerchantAuth::getReviewTime).page(DatabaseContextHolder.page(param.getPaging()));
        return DatabaseContextHolder.pagination(page, MerchantAuthCopier.INSTANCE::copying);
    }

    @Override
    public MerchantAuthDTO queryById() {
        Long userId = SessionContextHolder.getId();
        MerchantAuth merchantAuth = this.lambdaQuery()
                .eq(MerchantAuth::getApplicant, userId).one();
        MerchantAuthDTO merchantAuthDTO = MerchantAuthCopier.INSTANCE.copying(merchantAuth);
        if (merchantAuthDTO == null){
            return null;
        }
        merchantAuthDTO.setMerchant(this.merchantService.getMerchantByUserId(userId));
        return merchantAuthDTO;
    }

    @Override
    public void certificationAudit(Long id, String state,String message ) {
        Long userId = SessionContextHolder.getId();
        MerchantAuth merchantAuth = AssertUtils.available(this.getById(id), "商家认证不存在");
        merchantAuth.setReviewStatus(state);
        merchantAuth.setReviewTime(new Date());
        merchantAuth.setReviewer(userId.toString());
        merchantAuth.setMessage(message);
        this.updateById(merchantAuth);
        if (StringUtils.notEmpty(state) && "1".equals(state)){
            this.userClient.updateUserRole(merchantAuth.getApplicant());
        }
    }
}
